pitchtools.set_ascending_named_chromatic_pitches_on_nontied_pitched_components_in_expr
======================================================================================

.. autofunction:: abjad.tools.pitchtools.set_ascending_named_chromatic_pitches_on_nontied_pitched_components_in_expr.set_ascending_named_chromatic_pitches_on_nontied_pitched_components_in_expr
